@@ -21,7 +21,7 @@ from .direct_model import DataMixin
 
 # pylint: disable=unused-import
 try:
-    from typing import Dict, Union, Tuple, Any
+    from typing import Dict, Union, Tuple, Any, Optional
     from .data import Data1D, Data2D
     from .kernel import KernelModel
     from .modelinfo import ModelInfo
@@ -40,14 +40,12 @@ except ImportError:
     pass
 
 
-def create_parameters(model_info,  # type: ModelInfo
-                      **kwargs     # type: Union[float, str, Parameter]
-                     ):
-    # type: (...) -> Tuple[Dict[str, Parameter], Dict[str, str]]
+def create_parameters(model_info, **kwargs):
+    # type: (ModelInfo, Union[float, str, Parameter]) -> Tuple[Dict[str, Parameter], Dict[str, str]]
     """
     Generate Bumps parameters from the model info.
 
-    *model_info* is returned from :func:`generate.model_info` on the
+    *model_info* is returned from :func:`.generate.model_info` on the
     model definition module.
 
     Any additional *key=value* pairs are initial values for the parameters
@@ -86,7 +84,7 @@ class Model(object):
     """
     Bumps wrapper for a SAS model.
 
-    *model* is a runnable module as returned from :func:`core.load_model`.
+    *model* is a runnable module as returned from :func:`.core.load_model`.
 
     *cutoff* is the polydispersity weight cutoff.
 
@@ -125,9 +123,9 @@ class Experiment(DataMixin):
     r"""
     Bumps wrapper for a SAS experiment.
 
-    *data* is a :class:`data.Data1D`, :class:`data.Data2D` or
-    :class:`data.Sesans` object.  Use :func:`data.empty_data1D` or
-    :func:`data.empty_data2D` to define $q, \Delta q$ calculation
+    *data* is a :class:`.data.Data1D`, :class:`.data.Data2D` or
+    :class:`.data.SesansData` object.  Use :func:`.data.empty_data1D` or
+    :func:`.data.empty_data2D` to define $q, \Delta q$ calculation
     points for displaying the SANS curve when there is no measured data.
 
     *model* is a :class:`Model` object.
@@ -139,7 +137,7 @@ class Experiment(DataMixin):
     """
     _cache = None # type: Dict[str, np.ndarray]
     def __init__(self, data, model, cutoff=1e-5, name=None, extra_pars=None):
-        # type: (Data, Model, float) -> None
+        # type: (Data, Model, float, Optional[str], Optional[Dict[str, Parameter]]) -> None
         # Allow resolution function to define fittable parameters.  We do this
         # by creating reference parameters within the resolution object rather
         # than modifying the object itself to use bumps parameters.  We need
@@ -182,7 +180,7 @@ class Experiment(DataMixin):
     def resolution(self):
         # type: () -> Union[None, Resolution]
         """
-        :class:`sasmodels.Resolution` applied to the data, if any.
+        :class:`.resolution.Resolution` applied to the data, if any.
         """
         return self._resolution
 
@@ -190,7 +188,7 @@ class Experiment(DataMixin):
     def resolution(self, value):
         # type: (Resolution) -> None
         """
-        :class:`sasmodels.Resolution` applied to the data, if any.
+        :class:`.resolution.Resolution` applied to the data, if any.
         """
         self._resolution = value
 
