@@ -10,19 +10,19 @@ trig, etc., and may not be completely IEEE 754 compliant.  This lets
 make sure that the model calculations are stable, or if you need to
 tag the model as double precision only.
 
-Run using ./compare.sh (Linux, Mac) or compare.bat (Windows) in the
-sasmodels root to see the command line options.
+Run using "./sascomp -h" in the sasmodels root to see the command
+line options. To run from from an installed version of sasmodels,
+use "python -m sasmodels.compare -h".
 
 Note that there is no way within sasmodels to select between an
 OpenCL CPU device and a GPU device, but you can do so by setting the
-PYOPENCL_CTX environment variable ahead of time.  Start a python
-interpreter and enter::
+SAS_OPENCL environment variable. Start a python interpreter and enter::
 
     import pyopencl as cl
     cl.create_some_context()
 
 This will prompt you to select from the available OpenCL devices
-and tell you which string to use for the PYOPENCL_CTX variable.
+and tell you which string to use for the SAS_OPENCL variable.
 On Windows you will need to remove the quotes.
 """
 
@@ -48,7 +48,7 @@ from .generate import FLOAT_RE, set_integration_size
 
 # pylint: disable=unused-import
 try:
-    from typing import Optional, Dict, Any, Callable, Tuple
+    from typing import Optional, Dict, Any, Callable, Tuple, List
 except ImportError:
     pass
 else:
@@ -155,16 +155,6 @@ Examples:
     sascomp pringle -engine=single,double -timing=100,100 -noplot
 """
 
-# Update docs with command line usage string.   This is separate from the usual
-# doc string so that we can display it at run time if there is an error.
-# lin
-__doc__ = (__doc__  # pylint: disable=redefined-builtin
-           + """
-Program description
--------------------
-
-""" + USAGE)
-
 kerneldll.ALLOW_SINGLE_PRECISION_DLLS = True
 
 def build_math_context():
@@ -320,7 +310,6 @@ def parameter_range(p, v):
 
 def _randomize_one(model_info, name, value):
     # type: (ModelInfo, str, float) -> float
-    # type: (ModelInfo, str, str) -> str
     """
     Randomize a single parameter.
     """
@@ -392,7 +381,7 @@ def _randomize_one(model_info, name, value):
     return np.random.uniform(*limits)
 
 def _random_pd(model_info, pars, is2d):
-    # type: (ModelInfo, Dict[str, float]) -> None
+    # type: (ModelInfo, Dict[str, float], bool) -> None
     """
     Generate a random dispersity distribution for the model.
 
@@ -488,7 +477,7 @@ def _random_pd(model_info, pars, is2d):
 
 
 def randomize_pars(model_info, pars, maxdim=np.inf, is2d=False):
-    # type: (ModelInfo, ParameterSet, float) -> ParameterSet
+    # type: (ModelInfo, ParameterSet, float, bool) -> ParameterSet
     """
     Generate random values for all of the parameters.
 
@@ -518,7 +507,7 @@ def limit_dimensions(model_info, pars, maxdim):
             pars[p.name] = maxdim*10**np.random.uniform(-3, 0)
 
 def _swap_pars(pars, a, b):
-    # type: (ModelInfo, str, str) -<> None
+    # type: (ModelInfo, str, str) -> None
     """
     Swap polydispersity and magnetism when swapping parameters.
 
@@ -632,7 +621,7 @@ def parlist(model_info, pars, is2d):
 
 def _format_par(name, value=0., pd=0., n=0, nsigma=3., pdtype='gaussian',
                 relative_pd=False, M0=0., mphi=0., mtheta=0.):
-    # type: (str, float, float, int, float, str) -> str
+    # type: (str, float, float, int, float, str, bool, float, float, float) -> str
     line = "%s: %g"%(name, value)
     if pd != 0.  and n != 0:
         if relative_pd:
@@ -686,7 +675,7 @@ def time_calculation(calculator, pars, evals=1):
     return value, average_time
 
 def make_data(opts):
-    # type: (Dict[str, Any], float) -> Tuple[Data, np.ndarray]
+    # type: (Dict[str, Any]) -> Tuple[Data, np.ndarray]
     """
     Generate an empty dataset, used with the model to set Q points
     and resolution.
@@ -715,39 +704,8 @@ def make_data(opts):
         index = slice(None, None)
     return data, index
 
-DTYPE_MAP = {
-    'half': '16',
-    'fast': 'fast',
-    'single': '32',
-    'double': '64',
-    'quad': '128',
-    'f16': '16',
-    'f32': '32',
-    'f64': '64',
-    'float16': '16',
-    'float32': '32',
-    'float64': '64',
-    'float128': '128',
-    'longdouble': '128',
-}
-def eval_opencl(model_info, data, dtype='single', cutoff=0.):
-    # type: (ModelInfo, Data, str, float) -> Calculator
-    """
-    Return a model calculator using the OpenCL calculation engine.
-    """
-
-def eval_ctypes(model_info, data, dtype='double', cutoff=0.):
-    # type: (ModelInfo, Data, str, float) -> Calculator
-    """
-    Return a model calculator using the DLL calculation engine.
-    """
-    model = core.build_model(model_info, dtype=dtype, platform="dll")
-    calculator = DirectModel(data, model, cutoff=cutoff)
-    calculator.engine = "OMP%s"%DTYPE_MAP[str(model.dtype)]
-    return calculator
-
 def make_engine(model_info, data, dtype, cutoff, ngauss=0):
-    # type: (ModelInfo, Data, str, float) -> Calculator
+    # type: (ModelInfo, Data, str, float, int) -> Calculator
     """
     Generate the appropriate calculation engine for the given datatype.
 
@@ -783,7 +741,7 @@ def _show_invalid(data, theory):
 
 
 def compare(opts, limits=None, maxdim=None):
-    # type: (Dict[str, Any], Optional[Tuple[float, float]]) -> Tuple[float, float]
+    # type: (Dict[str, Any], Optional[Tuple[float, float]], Optional[float]) -> Tuple[float, float]
     """
     Preform a comparison using options from the command line.
 
@@ -802,8 +760,8 @@ def compare(opts, limits=None, maxdim=None):
     for k in range(opts['sets']):
         if k > 0:
             # print a separate seed for each dataset for better reproducibility
-            new_seed = np.random.randint(1000000)
-            print("=== Set %d uses -random=%i ==="%(k+1, new_seed))
+            new_seed = np.random.randint(1000000)  # type: int
+            print("=== Set %d uses -random=%d ===" % (k+1, new_seed))
             np.random.seed(new_seed)
         opts['pars'] = parse_pars(opts, maxdim=maxdim)
         if opts['pars'] is None:
@@ -843,15 +801,15 @@ def compare(opts, limits=None, maxdim=None):
     return limits
 
 def plot_profile(model_info, label='base', **args):
-    # type: (ModelInfo, List[Tuple[float, np.ndarray, np.ndarray]]) -> None
+    # type: (ModelInfo, List[Tuple[float, np.ndarray, np.ndarray]], float) -> None
     """
     Plot the profile returned by the model profile method.
 
     *model_info* defines model parameters, etc.
 
-    *mesh* is a list of tuples containing (*value*, *dispersity*, *weights*)
-    for each parameter, where (*dispersity*, *weights*) pairs are the
-    distributions to be plotted.
+    *label* is the legend label for the plotted line.
+
+    *args* are *parameter=value* pairs for the model profile function.
     """
     import pylab
 
@@ -872,7 +830,7 @@ def plot_profile(model_info, label='base', **args):
 
 
 def run_models(opts, verbose=False):
-    # type: (Dict[str, Any]) -> Dict[str, Any]
+    # type: (Dict[str, Any], bool) -> Dict[str, Any]
     """
     Process a parameter set, return calculation results and times.
     """
@@ -949,9 +907,9 @@ def _print_stats(label, err):
 
 
 def plot_models(opts, result, limits=None, setnum=0):
-    # type: (Dict[str, Any], Dict[str, Any], Optional[Tuple[float, float]]) -> Tuple[float, float]
+    # type: (Dict[str, Any], Dict[str, Any], Optional[Tuple[float, float]], int) -> Tuple[float, float]
     """
-    Plot the results from :func:`run_model`.
+    Plot the results from :func:`run_models`.
     """
     import matplotlib.pyplot as plt
 
@@ -1110,7 +1068,7 @@ def columnize(items, indent="", width=None):
 
 
 def get_pars(model_info):
-    # type: (ModelInfo, bool) -> ParameterSet
+    # type: (ModelInfo) -> ParameterSet
     """
     Extract default parameters from the model definition.
     """
@@ -1195,7 +1153,7 @@ def parse_opts(argv):
         return None
 
     # Check that a model was given on the command line
-    if len(positional_args) == 0:
+    if not positional_args:
         print("usage: ./sascomp [-?] [-models] model")
         return None
 
@@ -1561,10 +1519,10 @@ def parse_pars(opts, maxdim=None):
     # Hack to load user-defined distributions; run through all parameters
     # and make sure any pd_type parameter is a defined distribution.
     if (any(p.endswith('pd_type') and v not in weights.DISTRIBUTIONS
-            for p, v in pars.items()) or
-        any(p.endswith('pd_type') and v not in weights.DISTRIBUTIONS
-            for p, v in pars2.items())):
-       weights.load_weights()
+            for p, v in pars.items())
+            or any(p.endswith('pd_type') and v not in weights.DISTRIBUTIONS
+                   for p, v in pars2.items())):
+        weights.load_weights()
 
     if opts['show_pars']:
         if model_info.name != model_info2.name or pars != pars2:
