@@ -23,13 +23,14 @@ from .details import make_details
 
 # pylint: disable=unused-import
 try:
-    from typing import List
+    from typing import List, Tuple, Optional, Callable, Any
+    from .details import CallDetails
 except ImportError:
     pass
 # pylint: enable=unused-import
 
 def make_mixture_info(parts, operation='+'):
-    # type: (List[ModelInfo]) -> ModelInfo
+    # type: (List[ModelInfo], str) -> ModelInfo
     """
     Create info block for mixture model.
     """
@@ -145,7 +146,6 @@ def make_mixture_info(parts, operation='+'):
     model_info.random = random
     #model_info.single = any(part['single'] for part in parts)
     model_info.structure_factor = False
-    model_info.variant_info = None
     #model_info.tests = []
     #model_info.source = []
     # Remember the component info blocks so we can build the model
@@ -184,7 +184,7 @@ class MixtureModel(KernelModel):
 
 
 def _intermediates(q, results):
-    # type: (List[Tuple[Kernel, np.ndarray, Optional[Callable]]]) -> OrderedDict[str, Any]
+    # type: (np.ndarray, List[Tuple[Kernel, np.ndarray, Optional[Callable]]]) -> OrderedDict[str, Any]
     """
     Returns intermediate results for mixture model.
     """
@@ -212,7 +212,7 @@ class MixtureKernel(Kernel):
         self.results = None  # type: Callable[[], OrderedDict]
 
     def Iq(self, call_details, values, cutoff, magnetic):
-        # type: (CallDetails, np.ndarray, np.ndarry, float, bool) -> np.ndarray
+        # type: (CallDetails, np.ndarray, np.ndarray, float, bool) -> np.ndarray
         scale, background = values[0:2]
         total = 0.0
         # remember the parts for plotting later
@@ -269,7 +269,7 @@ class _MixtureParts(object):
         #call_details.show(values)
 
     def __iter__(self):
-        # type: () -> PartIterable
+        # type: () -> _MixtureParts
         self.part_num = 0
         self.par_index = 2
         self.mag_index = self.spin_index + 3
