@@ -23,9 +23,9 @@ primary particle, $V_\text{lattice}$ is a volume correction for the crystal
 structure, $P(q)$ is the form factor of the sphere (normalized), and $Z(q)$
 is the paracrystalline structure factor for a body-centered cubic structure.
 
-Equation (1) of the 1990 reference\ [#Matsuoka1990]_ is used to calculate $Z(q)$,
-using equations (29)-(31) from the 1987 paper\ [#Matsuoka1987]_ for $Z1$, $Z2$, and
-$Z3$.
+Equation (1) of the 1990 reference\ [#Matsuoka1990]_ is used to calculate
+$Z(q)$, using equations (29)-(31) from the 1987 paper\ [#Matsuoka1987]_ for
+$Z1$, $Z2$, and $Z3$.
 
 The lattice correction (the occupied volume of the lattice) for a
 body-centered cubic structure of particles of radius $R$ and nearest neighbor
@@ -70,21 +70,20 @@ correspond to (just the first 5)
 
 .. note::
 
-  The calculation of $Z(q)$ is a double numerical integral that
-  must be carried out with a high density of points to properly capture
-  the sharp peaks of the paracrystalline scattering.
-  So be warned that the calculation is slow. Fitting of any experimental data
-  must be resolution smeared for any meaningful fit. This makes a triple integral
-  which may be very slow.
+  The calculation of $Z(q)$ is a double numerical integral that must be
+  carried out with a high density of points to properly capture the sharp
+  peaks of the paracrystalline scattering. So be warned that the calculation
+  is slow. Fitting of any experimental data must be resolution smeared for
+  any meaningful fit. This makes a triple integral which may be very slow.
 
 This example dataset is produced using 200 data points,
 *qmin* = 0.001 |Ang^-1|, *qmax* = 0.1 |Ang^-1| and the above default values.
 
 The 2D (Anisotropic model) is based on the reference below where $I(q)$ is
-approximated for 1d scattering. Thus the scattering pattern for 2D may not
-be accurate, particularly at low $q$. For general details of the calculation and angular
-dispersions for oriented particles see :ref:`orientation` .
-Note that we are not responsible for any incorrectness of the 2D model computation.
+approximated for 1d scattering. Thus the scattering pattern for 2D may not be
+accurate, particularly at low $q$. For general details of the calculation and
+angular dispersions for oriented particles see :ref:`orientation`. Note that
+we are not responsible for any incorrectness of the 2D model computation.
 
 .. figure:: img/parallelepiped_angle_definition.png
 
@@ -94,10 +93,10 @@ Note that we are not responsible for any incorrectness of the 2D model computati
 References
 ----------
 
-.. [#Matsuoka1987] Hideki Matsuoka et. al. *Physical Review B*, 36 (1987) 1754-1765
-   (Original Paper)
-.. [#Matsuoka1990] Hideki Matsuoka et. al. *Physical Review B*, 41 (1990) 3854 -3856
-   (Corrections to FCC and BCC lattice structure calculation)
+.. [#Matsuoka1987] Hideki Matsuoka et. al. *Physical Review B*, 36 (1987)
+   1754-1765 (Original Paper)
+.. [#Matsuoka1990] Hideki Matsuoka et. al. *Physical Review B*, 41 (1990)
+   3854-3856 (Corrections to FCC and BCC lattice structure calculation)
 
 Authorship and Verification
 ---------------------------
