@@ -16,7 +16,7 @@ code is used to figure out what special parameters we have, where to
 find them in the P@S model inputs and how to distribute them to the underlying
 P and S model calculators.
 
-The parameter packet received by the P@S is a :class:`details.CallDetails`
+The parameter packet received by the P@S is a :class:`.details.CallDetails`
 structure along with a data vector. The CallDetails structure indicates which
 parameters are polydisperse, the length of the distribution, and where to
 find it in the data vector.  The distributions are ordered from longest to
@@ -125,11 +125,14 @@ from .details import make_details
 
 # pylint: disable=unused-import
 try:
-    from typing import Tuple, Callable, Union
+    from typing import OrderedDict as OrderedDictType
+    import typing
+    from typing import Tuple, Callable, Union, List, Optional, Dict
+    from .modelinfo import ParameterSet, Parameter
+    from .details import CallDetails
+    Parts = Dict[str, Union[float, np.ndarray, Tuple[np.ndarray, np.ndarray]]]
 except ImportError:
     pass
-else:
-    from .modelinfo import ParameterSet, Parameter
 # pylint: enable=unused-import
 
 # TODO: make shape averages available to constraints
@@ -237,7 +240,6 @@ def make_product_info(p_info, s_info):
     model_info.random = random
     #model_info.single = p_info.single and s_info.single
     model_info.structure_factor = False
-    model_info.variant_info = None
     #model_info.tests = []
     #model_info.source = []
     # Remember the component info blocks so we can build the model
@@ -281,24 +283,14 @@ def _tag_parameter(par):
     par.name = par.id + vector_length
     return par
 
-def _intermediates(
-        Q,                # type: np.ndarray
-        F,                # type: np.ndarray
-        Fsq,              # type: np.ndarray
-        S,                # type: np.ndarray
-        scale,            # type: float
-        volume,           # type: float
-        volume_ratio,     # type: float
-        radius_effective, # type: float
-        beta_mode,        # type: bool
-        P_intermediate,   # type: Optional[Callable[[], OrderedDict]
-    ):
-    # type: (...) -> OrderedDict[str, Union[np.ndarray, float]]
+def _intermediates(Q, F, Fsq, S, scale, volume, volume_ratio, radius_effective,
+                   beta_mode, P_intermediate):
+    # type: (np.ndarray, np.ndarray, np.ndarray, np.ndarray, float, float, float, float, bool, Optiona[Callable[[], Parts]]) -> Parts
     """
     Returns intermediate results for beta approximation-enabled product.
     The result may be an array or a float.
     """
-    parts = OrderedDict()
+    parts = OrderedDict()  # type: Parts
     parts["P(Q)"] = (Q, scale*Fsq)
     if P_intermediate is not None:
         parts["P(Q) parts"] = P_intermediate()
@@ -316,6 +308,10 @@ class ProductModel(KernelModel):
     """
     Model definition for product model.
     """
+    info = None  # type: ModelInfo
+    P = None  # type: KernelModel
+    S = None  # type: KernelModel
+    dtype = None  # type: np.dtype
     def __init__(self, model_info, P, S):
         # type: (ModelInfo, KernelModel, KernelModel) -> None
         #: Combined info plock for the product model
@@ -524,8 +520,10 @@ class ProductKernel(Kernel):
         # equal to form volume.  If P already has a volfraction parameter,
         # then assume that it is already on absolute scale, and don't
         # include volfrac in the combined_scale.
-        combined_scale = scale*(volfrac if not self._volfrac_in_p else 1.0)
-        final_result = combined_scale/shell_volume*PS + background
+        combined_scale = scale/shell_volume
+        if not self._volfrac_in_p:
+            combined_scale *= volfrac
+        final_result = combined_scale*PS + background
 
         # Capture intermediate values so user can see them.  These are
         # returned as a lazy evaluator since they are only needed in the
