@@ -88,18 +88,19 @@ class Pinhole1D(Resolution):
                        if q_calc is None else np.sort(q_calc))
 
         # Protect against models which are not defined for very low q.  Limit
-        # the smallest q value evaluated to 0.02*min.  Note that negative q
-        # values are trimmed even for broad resolution.  Although not possible
-        # from the geometry, they may appear since we are using a truncated
-        # gaussian to represent resolution rather than a skew distribution.
-        #cutoff = MINIMUM_ABSOLUTE_Q*np.min(self.q)
-        #self.q_calc = self.q_calc[self.q_calc >= cutoff]
+        # the smallest q value evaluated (in absolute) to 0.02*min
+        cutoff = MINIMUM_ABSOLUTE_Q*np.min(self.q)
+        self.q_calc = self.q_calc[abs(self.q_calc) >= cutoff]
 
         # Build weight matrix from calculated q values
         self.weight_matrix = pinhole_resolution(
             self.q_calc, self.q, np.maximum(q_width, MINIMUM_RESOLUTION),
             nsigma=nsigma)
 
+        # Force positive q, even for events measured on the opposite side of
+        # the beam stop.
+        self.q_calc = abs(self.q_calc)
+
     def apply(self, theory):
         return apply_resolution_matrix(self.weight_matrix, theory)
 
@@ -117,7 +118,7 @@ class Slit1D(Resolution):
     *q_calc* is the list of points to calculate, or None if this should
     be estimated from the *q* and *q_width*.
 
-    The *weight_matrix* is computed by :func:`slit1d_resolution`
+    The *weight_matrix* is computed by :func:`slit_resolution`
     """
     def __init__(self, q, qx_width, qy_width=0., q_calc=None):
         # Remember what width/dqy was used even though we won't need them
@@ -549,7 +550,7 @@ def romberg_slit_1d(q, width, height, form, pars):
     """
     from scipy.integrate import romberg  # type: ignore
 
-    par_set = set([p.name for p in form.info.parameters.call_parameters])
+    par_set = {p.name for p in form.info.parameters.call_parameters}
     if any(k not in par_set for k in pars.keys()):
         extra = set(pars.keys()) - par_set
         raise ValueError("bad parameters: [%s] not in [%s]"
@@ -604,7 +605,7 @@ def romberg_pinhole_1d(q, q_width, form, pars, nsigma=2.5):
     """
     from scipy.integrate import romberg  # type: ignore
 
-    par_set = set([p.name for p in form.info.parameters.call_parameters])
+    par_set = {p.name for p in form.info.parameters.call_parameters}
     if any(k not in par_set for k in pars.keys()):
         extra = set(pars.keys()) - par_set
         raise ValueError("bad parameters: [%s] not in [%s]"
@@ -1107,7 +1108,7 @@ def _eval_demo_1d(resolution, title):
         pars = {'length':210, 'radius':500, 'background': 0}
     elif name == 'teubner_strey':
         pars = {'a2':0.003, 'c1':-1e4, 'c2':1e10, 'background':0.312643}
-    elif name == 'sphere' or name == 'spherepy':
+    elif name in ('sphere', 'spherepy'):
         pars = TEST_PARS_SLIT_SPHERE
     elif name == 'ellipsoid':
         pars = {
